==> jc-1.4.0.tar.gz: soot/jimple/spark/pag/ClassConstantNode.h <==
// public class soot.jimple.spark.pag.ClassConstantNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5773deea6ecc5e2a soot_jimple_spark_pag_AllocNode
// @dep_class 7b90116163633932 soot_jimple_spark_pag_ClassConstantNode
// @dep_class 1f5a22eefeebbf06 soot_jimple_spark_pag_Node

// header file dependencies
// @dep_header soot_jimple_spark_pag_AllocNode

#include "soot/jimple/spark/pag/AllocNode.h"

#ifndef _JC_soot_jimple_spark_pag_ClassConstantNode_H_
#define _JC_soot_jimple_spark_pag_ClassConstantNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_ClassConstantNode$sub_refs	_jc_soot_jimple_spark_pag_ClassConstantNode$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_ClassConstantNode$sub_nonrefs	_jc_soot_jimple_spark_pag_ClassConstantNode$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_ClassConstantNode$refs	_jc_soot_jimple_spark_pag_ClassConstantNode$refs;
typedef struct _jc_soot_jimple_spark_pag_ClassConstantNode$nonrefs	_jc_soot_jimple_spark_pag_ClassConstantNode$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_ClassConstantNode$object	_jc_soot_jimple_spark_pag_ClassConstantNode$object;

typedef const struct _jc_soot_jimple_spark_pag_ClassConstantNode$vmethods	_jc_soot_jimple_spark_pag_ClassConstantNode$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_ClassConstantNode$vtable	_jc_soot_jimple_spark_pag_ClassConstantNode$vtable;
typedef const struct _jc_soot_jimple_spark_pag_ClassConstantNode$vtype	_jc_soot_jimple_spark_pag_ClassConstantNode$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_ClassConstantNode$method$_init$be3769f0ccb0440f(_jc_env *, struct _jc_soot_jimple_spark_pag_ClassConstantNode$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_ClassConstantNode$method$getString$fb8e0f9b9b45f51c(_jc_env *, struct _jc_soot_jimple_spark_pag_ClassConstantNode$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_ClassConstantNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_pag_ClassConstantNode$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_ClassConstantNode$method_info$getString$fb8e0f9b9b45f51c;
extern _jc_method _jc_soot_jimple_spark_pag_ClassConstantNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_ClassConstantNode$vmethods {
	struct _jc_java_lang_String$object	*(*getString$fb8e0f9b9b45f51c)(_jc_env *, struct _jc_soot_jimple_spark_pag_ClassConstantNode$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_pag_ClassConstantNode$object *);
};

// Vtable
struct _jc_soot_jimple_spark_pag_ClassConstantNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Node$vmethods	soot_jimple_spark_pag_Node;
	_jc_soot_jimple_spark_pag_AllocNode$vmethods	soot_jimple_spark_pag_AllocNode;
	_jc_soot_jimple_spark_pag_ClassConstantNode$vmethods	soot_jimple_spark_pag_ClassConstantNode;
};

// Vtype
struct _jc_soot_jimple_spark_pag_ClassConstantNode$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_ClassConstantNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_ClassConstantNode$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_ClassConstantNode$refs {
    _jc_soot_jimple_spark_pag_ClassConstantNode$sub_refs	soot_jimple_spark_pag_ClassConstantNode;
    _jc_soot_jimple_spark_pag_AllocNode$sub_refs	soot_jimple_spark_pag_AllocNode;
    _jc_soot_jimple_spark_pag_Node$sub_refs	soot_jimple_spark_pag_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_ClassConstantNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_ClassConstantNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Node$sub_nonrefs	soot_jimple_spark_pag_Node;
    _jc_soot_jimple_spark_pag_AllocNode$sub_nonrefs	soot_jimple_spark_pag_AllocNode;
    _jc_soot_jimple_spark_pag_ClassConstantNode$sub_nonrefs	soot_jimple_spark_pag_ClassConstantNode;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_ClassConstantNode$object {
	_jc_soot_jimple_spark_pag_ClassConstantNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_ClassConstantNode$vtype	*vtype;
	_jc_soot_jimple_spark_pag_ClassConstantNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_ClassConstantNode$vtype _jc_soot_jimple_spark_pag_ClassConstantNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_ClassConstantNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_ClassConstantNode$class_object;

#endif	/* _JC_soot_jimple_spark_pag_ClassConstantNode_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/pag/ClassConstantNode.h <==
// public class soot.jimple.spark.pag.ClassConstantNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5773deea6ecc5e2a soot_jimple_spark_pag_AllocNode
// @dep_class 7b90116163633932 soot_jimple_spark_pag_ClassConstantNode
// @dep_class 1f5a22eefeebbf06 soot_jimple_spark_pag_Node

// header file dependencies
// @dep_header soot_jimple_spark_pag_AllocNode

#include "soot/jimple/spark/pag/AllocNode.h"

#ifndef _JC_soot_jimple_spark_pag_ClassConstantNode_H_
#define _JC_soot_jimple_spark_pag_ClassConstantNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_ClassConstantNode$sub_refs	_jc_soot_jimple_spark_pag_ClassConstantNode$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_ClassConstantNode$sub_nonrefs	_jc_soot_jimple_spark_pag_ClassConstantNode$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_ClassConstantNode$refs	_jc_soot_jimple_spark_pag_ClassConstantNode$refs;
typedef struct _jc_soot_jimple_spark_pag_ClassConstantNode$nonrefs	_jc_soot_jimple_spark_pag_ClassConstantNode$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_ClassConstantNode$object	_jc_soot_jimple_spark_pag_ClassConstantNode$object;

typedef const struct _jc_soot_jimple_spark_pag_ClassConstantNode$vmethods	_jc_soot_jimple_spark_pag_ClassConstantNode$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_ClassConstantNode$vtable	_jc_soot_jimple_spark_pag_ClassConstantNode$vtable;
typedef const struct _jc_soot_jimple_spark_pag_ClassConstantNode$vtype	_jc_soot_jimple_spark_pag_ClassConstantNode$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_ClassConstantNode$method$_init$be3769f0ccb0440f(_jc_env *, struct _jc_soot_jimple_spark_pag_ClassConstantNode$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_ClassConstantNode$method$getString$fb8e0f9b9b45f51c(_jc_env *, struct _jc_soot_jimple_spark_pag_ClassConstantNode$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_ClassConstantNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_pag_ClassConstantNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_ClassConstantNode$method_info$getString$fb8e0f9b9b45f51c;
extern _jc_method _jc_soot_jimple_spark_pag_ClassConstantNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_ClassConstantNode$vmethods {
	struct _jc_java_lang_String$object	*(*getString$fb8e0f9b9b45f51c)(_jc_env *, struct _jc_soot_jimple_spark_pag_ClassConstantNode$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_pag_ClassConstantNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_pag_ClassConstantNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Node$vmethods	soot_jimple_spark_pag_Node;
	_jc_soot_jimple_spark_pag_AllocNode$vmethods	soot_jimple_spark_pag_AllocNode;
	_jc_soot_jimple_spark_pag_ClassConstantNode$vmethods	soot_jimple_spark_pag_ClassConstantNode;
};

// Vtype
struct _jc_soot_jimple_spark_pag_ClassConstantNode$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_ClassConstantNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_ClassConstantNode$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_ClassConstantNode$refs {
    _jc_soot_jimple_spark_pag_ClassConstantNode$sub_refs	soot_jimple_spark_pag_ClassConstantNode;
    _jc_soot_jimple_spark_pag_AllocNode$sub_refs	soot_jimple_spark_pag_AllocNode;
    _jc_soot_jimple_spark_pag_Node$sub_refs	soot_jimple_spark_pag_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_ClassConstantNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_ClassConstantNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Node$sub_nonrefs	soot_jimple_spark_pag_Node;
    _jc_soot_jimple_spark_pag_AllocNode$sub_nonrefs	soot_jimple_spark_pag_AllocNode;
    _jc_soot_jimple_spark_pag_ClassConstantNode$sub_nonrefs	soot_jimple_spark_pag_ClassConstantNode;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_ClassConstantNode$object {
	_jc_soot_jimple_spark_pag_ClassConstantNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_ClassConstantNode$vtype	*vtype;
	_jc_soot_jimple_spark_pag_ClassConstantNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_ClassConstantNode$vtype _jc_soot_jimple_spark_pag_ClassConstantNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_ClassConstantNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_ClassConstantNode$class_object;

#endif	/* _JC_soot_jimple_spark_pag_ClassConstantNode_H_ */
